import { useRef, forwardRef } from 'react';
import PropTypes from 'prop-types';
import loadable from '@loadable/component';
import useControlledState from '@s-ui/react-hooks/lib/useControlledState';
import { PLACEMENTS, TRIGGERS } from './config';
import PopoverExtendChildren from './PopoverExtendChildren';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
var BASE_CLASS = 'sui-AtomPopover';
var CLASS_INNER = BASE_CLASS + "-inner";
var PREFIX_PLACEMENT = BASE_CLASS + "-";
var DEFAULT_OFFSET = 'auto,4px';
var DEFAULT_TRIGGER = TRIGGERS.LEGACY;
var DEFAULT_DELAY = 0; // https://github.com/reactstrap/reactstrap/blob/8.9.0/src/Popover.js

var Popover = loadable(function () {
  return import('reactstrap/lib/Popover');
}, {
  ssr: true
});
var AtomPopover = /*#__PURE__*/forwardRef(function (_ref, outRef) {
  var children = _ref.children,
      closeIcon = _ref.closeIcon,
      content = _ref.content,
      onClose = _ref.onClose,
      onOpen = _ref.onOpen,
      _ref$placement = _ref.placement,
      placement = _ref$placement === void 0 ? PLACEMENTS.BOTTOM : _ref$placement,
      isVisible = _ref.isVisible,
      defaultIsVisible = _ref.defaultIsVisible,
      _ref$hideArrow = _ref.hideArrow,
      hideArrow = _ref$hideArrow === void 0 ? true : _ref$hideArrow,
      _ref$trigger = _ref.trigger,
      trigger = _ref$trigger === void 0 ? DEFAULT_TRIGGER : _ref$trigger;
  var targetRef = useRef();

  var _useControlledState = useControlledState(isVisible, defaultIsVisible),
      isVisibleState = _useControlledState[0],
      setIsVisibleState = _useControlledState[1];

  var handleToggle = function handleToggle(ev) {
    setIsVisibleState(!isVisibleState);
    isVisibleState ? typeof onClose === 'function' && onClose(ev) : typeof onOpen === 'function' && onOpen(ev);
  };

  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(PopoverExtendChildren, {
      ref: targetRef,
      onToggle: handleToggle,
      children: children
    }), /*#__PURE__*/_jsxs(Popover, {
      trigger: Array.isArray(trigger) ? trigger.join(' ') : trigger,
      isOpen: isVisibleState,
      toggle: handleToggle,
      target: targetRef,
      className: BASE_CLASS,
      popperClassName: "popperClassName",
      innerClassName: CLASS_INNER,
      arrowClassName: BASE_CLASS + "-arrow",
      innerRef: outRef,
      hideArrow: hideArrow,
      placementPrefix: PREFIX_PLACEMENT,
      delay: DEFAULT_DELAY,
      placement: placement,
      offset: DEFAULT_OFFSET,
      children: [closeIcon && /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-closeIcon",
        onClick: handleToggle,
        children: closeIcon
      }), content]
    })]
  });
});
AtomPopover.displayName = 'AtomPopover';
export { PLACEMENTS as atomPopoverPositions };
export { TRIGGERS as atomPopoverTriggers };
export default AtomPopover;